package com.zd.chemical.mapper;

import java.util.List;
import com.zd.chemical.domain.ActApplytask;

/**
 * 化学品申购任务Mapper接口
 *
 * @author zd
 * @date 2022-08-17
 */
public interface ActApplytaskMapper
{
    /**
     * 查询化学品申购任务
     *
     * @param id 化学品申购任务主键
     * @return 化学品申购任务
     */
    ActApplytask selectActApplytaskById(Long id);

    /**
     * 查询化学品申购任务列表
     *
     * @param actApplytask 化学品申购任务
     * @return 化学品申购任务集合
     */
    List<ActApplytask> selectActApplytaskList(ActApplytask actApplytask);

    /**
     * 根据主键集合查询化学品申购任务列表
     *
     * @param ids 主键集合
     * @return 化学品申购任务集合
     */
    List<ActApplytask> getListByIds(List <Long> ids);

    /**
     * 新增化学品申购任务
     *
     * @param actApplytask 化学品申购任务
     * @return 结果
     */
    int insertActApplytask(ActApplytask actApplytask);

    /**
     * 修改化学品申购任务
     *
     * @param actApplytask 化学品申购任务
     * @return 结果
     */
    int updateActApplytask(ActApplytask actApplytask);

    /**
     * 删除化学品申购任务
     *
     * @param id 化学品申购任务主键
     * @return 结果
     */
    int deleteActApplytaskById(Long id);

    /**
     * 批量删除化学品申购任务
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteActApplytaskByIds(Long[] ids);
}
