package com.zd.chemical.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.chemical.domain.vo.ActApplytaskVo;
import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.chemical.domain.ActApplytask;
import com.zd.chemical.service.IActApplytaskService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 化学品申购任务Controller
 *
 * @author zd
 * @date 2022-08-17
 */
@RestController
@Api(tags = "【化学品申购任务】")
@RequestMapping("/applytask")
public class ActApplytaskController extends BaseController<ActApplytask>
{
    @Autowired
    private IActApplytaskService actApplytaskService;

    /**
     * 查询化学品申购任务列表
     */
//    @PreAuthorize(hasPermi = "laboratory:applytask:list")
    @GetMapping("/list")
    @ApiOperation(value = "查询化学品申购任务列表")
    public TableDataInfo<ActApplytask> list(ActApplytask actApplytask)
    {
        startPage();
        List<ActApplytask> list = actApplytaskService.selectActApplytaskList(actApplytask);
        return getDataTable(list);
    }

    /**
     * 导出化学品申购任务列表
     */
    @ApiOperation(value = "导出化学品申购任务列表")
//    @PreAuthorize(hasPermi = "laboratory:applytask:export")
    @Log(title = "化学品申购任务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ActApplytask actApplytask) throws IOException
    {
        List<ActApplytask> list = actApplytaskService.selectActApplytaskList(actApplytask);
        ExcelUtil<ActApplytask> util = new ExcelUtil<ActApplytask>(ActApplytask.class);
        util.exportExcel(response, list, "化学品申购任务数据");
    }

    /**
     * 获取化学品申购任务详细信息
     */
    @ApiOperation(value = "获取化学品申购任务详细信息")
//    @PreAuthorize(hasPermi = "laboratory:applytask:query")
    @GetMapping(value = "/{id}")
    public ResultData<ActApplytask> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(actApplytaskService.selectActApplytaskById(id));
    }

    /**
     * 新增化学品申购任务
     */
    @ApiOperation(value = "新增化学品申购任务")
//    @PreAuthorize(hasPermi = "laboratory:applytask:add")
    @Log(title = "化学品申购任务", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody ActApplytask actApplytask)
    {
        return ResultData.result(actApplytaskService.insertActApplytask(actApplytask));
    }

    /**
     * 修改化学品申购任务
     */
    @ApiOperation(value = "修改化学品申购任务")
//    @PreAuthorize(hasPermi = "laboratory:applytask:edit")
    @Log(title = "化学品申购任务", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody ActApplytask actApplytask)
    {
        return  ResultData.result(actApplytaskService.updateActApplytask(actApplytask));
    }

    /**
     * 删除化学品申购任务
     */
    @ApiOperation(value = "删除化学品申购任务")
//    @PreAuthorize(hasPermi = "laboratory:applytask:remove")
    @Log(title = "化学品申购任务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(actApplytaskService.deleteActApplytaskByIds(ids));
    }


    /**
     * 工作流节点审批（审批通过）
     */
    @ApiOperation(value = "工作流节点审批")
    @PreAuthorize(hasPermi = PerPrefix.ACT_HXP_APPLYTASK+ PerFun.EDIT)
    @Log(title = "工作流节点审批任务", businessType = BusinessType.UPDATE)
    @PutMapping("/approvalTask")
    public ResultData approvalTask(@RequestBody ActApplytaskVo actApplytaskVo)
    {
        return  ResultData.result(actApplytaskService.approvalTask(actApplytaskVo));
    }

    /**
     * 工作流节点审批(拒绝)
     */
    @ApiOperation(value = "工作流节点审批(拒绝)")
    @PreAuthorize(hasPermi = PerPrefix.ACT_HXP_REFUSEAPPLYTASK+ PerFun.EDIT)
    @Log(title = "工作流节点审批任务(拒绝)", businessType = BusinessType.UPDATE)
    @PutMapping("/approvalRefuse")
    public ResultData approvalRefuse(@RequestBody ActApplytask actApplytask)
    {
        return  ResultData.result(actApplytaskService.approvalRefuse(actApplytask));
    }

    /**
     * 工作流节点审批(撤销)
     */
    @ApiOperation(value = "工作流节点审批(撤销)")
    @PreAuthorize(hasPermi = PerPrefix.ACT_HXP_REVOKEAPPLYTASK+ PerFun.EDIT)
    @Log(title = "工作流节点审批任务(撤销)", businessType = BusinessType.UPDATE)
    @PutMapping("/approvalRevoke")
    public ResultData approvalRevoke(@RequestBody ActApplytask actApplytask)
    {
        return  ResultData.result(actApplytaskService.approvalRevoke(actApplytask));
    }


    /**
     * 工作流节点审批(撤销学生端用)
     */
    @ApiOperation(value = "工作流节点审批(撤销)")
    @Log(title = "工作流节点审批任务(撤销)", businessType = BusinessType.UPDATE)
    @PutMapping("/myApprovalRevoke")
    public ResultData myApprovalRevoke(@RequestBody ActApplytask actApplytask)
    {
        return  ResultData.result(actApplytaskService.approvalRevoke(actApplytask));
    }
}
